@@ -9,7 +9,7 @@
 #
 package CatalystX::Controller::ExtJS::REST;
 BEGIN {
-  $CatalystX::Controller::ExtJS::REST::VERSION = '1.124000';
+  $CatalystX::Controller::ExtJS::REST::VERSION = '2.0.0';
 }
 # ABSTRACT: RESTful interface to dbic objects
 
@@ -25,12 +25,15 @@ use Path::Class;
 use HTML::Entities;
 use Lingua::EN::Inflect;
 use JSON::Any;
+use Try::Tiny;
 
 use Moose::Util::TypeConstraints;
 subtype 'PathClassDir', as 'Path::Class::Dir';
 coerce 'PathClassDir', from 'ArrayRef', via { Path::Class::Dir->new( @{$_[0]} ) };
 coerce 'PathClassDir', from 'Str', via { Path::Class::Dir->new( $_[0] ) };
 subtype 'PathClassFile', as 'Path::Class::File';
+coerce 'PathClassFile', from 'ArrayRef', via { Path::Class::File->new( @{$_[0]} ) };
+coerce 'PathClassFile', from 'Str', via { Path::Class::File->new( $_[0] ) };
 no Moose::Util::TypeConstraints;
 
 __PACKAGE__->config(
@@ -71,13 +74,13 @@ has '_extjs_config' => ( is => 'rw', isa => 'HashRef', builder => '_extjs_config
 
 has 'form_base_path' => ( is => 'rw', lazy_build => 1, isa => 'PathClassDir', coerce => 1 );
 
-has 'form_base_file' => ( is => 'rw', lazy_build => 1, isa => 'Path::Class::File' );
+has 'form_base_file' => ( is => 'rw', lazy_build => 1, isa => 'PathClassFile', coerce => 1 );
 
 has 'list_base_path' => ( is => 'rw', lazy_build => 1, isa => 'PathClassDir', coerce => 1 );
 
-has 'list_base_file' => ( is => 'rw', lazy_build => 1, isa => 'Path::Class::File' );
+has 'list_base_file' => ( is => 'rw', lazy_build => 1, isa => 'PathClassFile', coerce => 1 );
 
-has 'list_options_file' => ( is => 'rw', lazy_build => 1, isa => 'PathClassFile|Undef' );
+has 'list_options_file' => ( is => 'rw', lazy_build => 1, isa => 'PathClassFile|Undef', coerce => 1 );
 
 has 'form_config_cache' => ( is => 'rw', isa => 'HashRef', clearer => 'clear_form_config_cache', default => sub {{}});
 
@@ -85,6 +88,12 @@ has 'default_resultset' => ( is => 'rw', isa => 'Str', lazy_build => 1 );
 
 has 'root_property'     => ( is => 'rw', isa => 'Str', default => 'data' );
 
+has 'limit' => ( is => 'rw', default => 100 );
+
+has 'order_by' => ( is => 'rw' );
+
+has 'forms' => ( is => 'rw', isa => 'HashRef', predicate => 'has_forms' );
+
 # backwards compat
 sub base_file { shift->form_base_file(@_) };
 sub base_path { shift->form_base_path(@_) };
@@ -107,7 +116,7 @@ sub _extjs_config_builder {
             elements => [
                 { name => 'start', constraints => ['Integer', { type => 'MinRange', min => 0}] },
                 { name => 'dir', constraints => { type => 'Set', set => [qw(asc desc ASC DESC)] } },
-                { name => 'limit', constraints => ['Integer', { type => 'Range', min => 0, max => 100 }] },
+                { name => 'limit', constraints => ['Integer', { type => 'Range', min => 0, max => $self->limit || 9999 }] },
                 { name => 'sort' },
             ]
         },
@@ -180,7 +189,11 @@ sub validate_options {
     my ($self, $c) = @_;
     my $form = HTML::FormFu::ExtJS->new;
     $form->populate($self->_extjs_config->{list_options_validation});
-    if($self->list_options_file) {
+    if($self->has_forms) {
+        my $config = $self->forms->{options} || {};
+        $config = { elements => $config } if(ref $config eq 'ARRAY');
+        $form->populate( $config );
+    } elsif($self->list_options_file) {
         $c->log->debug('found configuration file for parameters') if($c->debug);
         $form->load_config_file($self->list_options_file);
     }
@@ -191,8 +204,7 @@ sub validate_options {
 sub list {
     my ( $self, $c ) = @_;
 	$self->clear_caches if($c->debug);
-    $c->log->debug('Loading form ' . $self->list_base_file) if($c->debug);
-    my $form = $self->get_form($c, $self->list_base_file);
+    my $form = $self->get_form($c, 'list');
     my $config = $form->model_config;
     croak "Need resultset and schema" unless($config->{resultset} && $config->{schema});
     my $model = join('::', $config->{schema}, $config->{resultset});
@@ -201,7 +213,7 @@ sub list {
     
     if($validate_options->has_errors) {
         $self->status_bad_request($c, message => 'One ore more parameters did not pass the validation');
-        $c->stash->{rest} = { errors => $validate_options->validation_response->{errors} };
+        $c->stash->{rest} = { errors => $validate_options->validation_response->{errors}, status => \0 };
         return;
     }
 
@@ -221,7 +233,7 @@ sub list {
         }
     }
     push(@args, map { $_ => [] } $c->req->param('resultset'));
-    unshift(@args, $self->_extjs_config->{default_rs_method} => []);
+    unshift(@args, $self->_extjs_config->{default_rs_method} => ['list']);
     
     for(my $i = 0; $i < @args; $i+=2) {
         next unless(my $rs_method = $args[$i]);
@@ -262,20 +274,26 @@ sub paging_rs {
     
     my $start = abs(int($params->{start} || 0));
     
-    my $limit = abs(int($params->{limit} || 0));
+    my $limit = abs(int($params->{limit} || $self->limit));
 
     return $rs if($start == 0 && $limit == 0);
 
     my @direction = grep { $_ eq (lc($params->{dir}) || 'asc') } qw(asc desc);
     my $direction = q{-}.(shift @direction);
     
-    my $sort = $params->{sort} || undef;
+    my $sort = $params->{sort} || $self->order_by || undef;
+    if(ref $sort eq 'HASH') {
+        ($direction, $sort) = %$sort;
+    }
     
-    undef $sort unless($form->get_all_element({ nested_name => $sort }));
+    unless($form->get_all_element({ nested_name => $sort })) {
+        $sort =~ s/(?<=[a-z])([A-Z])/\.\l$1/gsx; # relationshipColumn => relationship.column
+        undef $sort unless($form->get_all_element({ nested_name => $sort }));
+    }
     
     my $paged = $rs->search(undef, { offset => $start, rows => $limit || undef});
-    my $me = $rs->current_source_alias;
-    $paged = $paged->search(undef, { order_by => [ { $direction => join('.', $me, $sort) } ] })
+    $sort = join('.', $rs->current_source_alias, $sort) unless(!$sort || $sort =~ /\./);
+    $paged = $paged->search(undef, { order_by => [ { $direction => $sort } ] })
       if $sort;
     return $paged;
 }
@@ -287,9 +305,9 @@ sub base {
 
 sub object {
     my ( $self, $c, $id ) = @_;
-    croak $self->form_base_file." cannot be found" unless(-e $self->form_base_file);
 	$self->clear_caches if($c->debug);
-    my $config = $self->load_config_file($self->form_base_file);
+    my $config = $self->has_forms ? $self->forms->{default} : $self->load_config_file($self->form_base_file);
+    $config = { elements => $config } if(ref $config eq 'ARRAY');
     $config = { %{$self->_extjs_config->{model_config}}, %{$config->{model_config} || {}} };
     $config->{resultset} ||= $self->default_resultset;
     croak "Need resultset and schema" unless($config->{resultset} && $config->{schema});
@@ -315,7 +333,7 @@ sub object {
     if(my $rs = $self->_extjs_config->{default_rs_method}) {
         if($object->can($rs)) {
             $c->log->debug(qq(Calling default resultset method $rs)) if($c->debug);
-            $object = $object->$rs($c);
+            $object = $object->$rs($c, 'object');
         } elsif($c->debug) {
             $c->log->debug(qq(Default resultset method $rs cannot be found));
         }
@@ -329,12 +347,8 @@ sub object {
         $c->stash->{object} = $object;
     }
 	
-	my $formconfig = $self->path_to_forms($req_method);
-	$c->log->debug('Loading form ' . $formconfig) if($c->debug);
-	
     $c->stash->{form} =
-      $self->get_form($c, $formconfig);
-    
+      $self->get_form($c, $req_method);
     if($req_method eq 'get') {
         $c->forward('object_GET');
     } elsif($req_method eq 'put' || $req_method eq 'post' && $c->stash->{object}) {
@@ -453,6 +467,7 @@ sub path_to_forms {
 
 sub get_form {
     my ($self, $c, $file) = @_;
+    
 	my $form = HTML::FormFu::ExtJS->new();
 	$form->query_type('Catalyst');
 	my $model_stash = $self->_extjs_config->{model_stash};
@@ -462,10 +477,27 @@ sub get_form {
 	}
 	$form->model_config($self->_extjs_config->{model_config});
 	
-	if($file) { 
-	    my $config = $self->load_config_file($file);
-	    $form->populate($config);	
+	
+
+   if ( $file && !ref $file ) {
+        if ( $self->has_forms ) {
+            my $config = $self->forms->{$file} || $self->forms->{default};
+            $config = { elements => $config } if(ref $config eq 'ARRAY');
+            $form->populate( $config );
+        } elsif ( $file eq 'list' ) {
+            $file = $self->list_base_file;
+        } else {
+            $file = $self->path_to_forms($file);
+        }
     }
+
+    if ( ref $file ) {
+        $c->log->debug( 'Loading form ' . $file ) if ( $c->debug );
+        my $config = $self->load_config_file($file);
+        $form->populate($config);
+    }
+
+
     # To allow your form validation packages, etc, access to the catalyst
     # context, a weakened reference of the context is copied into the form's
     # stash.
@@ -502,10 +534,22 @@ sub handle_uploads {
     $row->update;
 }
 
+sub status_not_found {
+    my $self = shift;
+    $self->next::method(@_);
+    shift->stash->{rest}->{success} = \0;
+}
 
 sub end {
     my ( $self, $c ) = @_;
     $self->next::method($c);
+    if(@{$c->error}) {
+        $self->status_bad_request($c, message => $c->debug ? "@{$c->error}" : 'An error occured while processing your request.');
+        $c->log->error(@{$c->error});
+        $c->clear_errors;
+        $c->stash->{rest}->{success} = \0;
+    }
+    
     if ( $c->req->is_ext_upload ) {
         my $stash_key = (
               $self->config->{'serialize'}
@@ -553,7 +597,7 @@ CatalystX::Controller::ExtJS::REST - RESTful interface to dbic objects
 
 =head1 VERSION
 
-version 1.124000
+version 2.0.0
 
 =head1 SYNOPSIS
 
@@ -590,8 +634,11 @@ If you create a controller C<MyApp::Controller::User>:
   
   1;
 
-You also need to create a file C<root/forms/user.yml>. To a more fine
-grained control over object creation, deletion, update or listing, you 
+Forms can be defined either in files or directly in the controller.
+To see how to define forms directly in the controller see L</forms>.
+
+If you are creating files, you need at least one file called C<root/forms/user.yml>.
+For a more fine grained control over object creation, deletion, update or listing, you 
 have to create some more files.
 
   root/
@@ -750,7 +797,9 @@ Defaults to C<find>.
 
 This resultset method is called on every request. This is useful if you want to 
 restrict the resultset, e. g. only find objects which are associated to the
-current user.
+current user. The first parameter is the Catalyst context object and the second
+parameter is either C<list> (if a list of objects has been requested) or C<object>
+(if only one object is manipulated).
 
 Nothing is called if the specified method does not exist.
 
@@ -779,6 +828,30 @@ Default value: C<context>
 
 Defaults to C<root/forms>
 
+=head2 forms
+
+If you define forms in the controller, files will not be loaded and are not required.
+You need to have at least the C<default> form defined. It is equivalent to the file
+without the request method appended.
+
+Example:
+
+  forms => {
+      default => [
+        { name => 'id' },
+        { name => 'title' },
+      ],
+      get => ...
+      list => ...
+      options => ...
+  }
+
+See C<< t/lib/MyApp/Controller/InlineUser.pm >> for a working example.
+
+=head2 limit
+
+The maximum number of rows to return. Defaults to 100.
+
 =head2 list_base_path
 
 Defaults to C<root/lists>
@@ -803,6 +876,14 @@ Defaults to L</default_resultset>
 
 Defaults to L<Catalyst::Controller/namespace>
 
+=head2 order_by
+
+Specify the default sort order. 
+
+Examples:
+ order_by => 'productid'
+ order_by => { -desc => 'updated_on' }
+
 =head2 list_namespace
 
 Defaults to the plural form of L</namespace>. If this is the same as L</namespace> C<list_> is prepended.
@@ -981,4 +1062,3 @@ This is free software, licensed under:
 
 __END__
 
-
